/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_EXPORT_MSA2SEQ_DIALOG_H_
#define _U2_EXPORT_MSA2SEQ_DIALOG_H_

#include <U2Core/global.h>

#include <QtGui/QDialog>
#include <ui/ui_ExportMSA2SequencesDialog.h>

namespace U2 {

class SaveDocumentGroupController;

class ExportMSA2SequencesDialog : public QDialog, Ui_ExportMSA2SequencesDialog {
    Q_OBJECT
public:
    ExportMSA2SequencesDialog(QWidget* p);

    virtual void accept();

public:
    QString url;
    DocumentFormatId format;
    bool    trimGapsFlag;
    bool    addToProjectFlag;

private:    
    SaveDocumentGroupController* saveContoller;
};

}//namespace

#endif
